        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <br>3,4,5,6,7,8,10,11,12,16,19,23,28,29,31,33,34,37,39,41,43,44';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 21 <strong>control</strong><br>0,1,9,14,20,21,22,24,25,26,27,30,32,36,40,42,45,47,48,49,50';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 8 <br>2,13,15,17,18,35,38,46';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <br>3,4,5,6,7,8,10,11,12,16,19,23,28,29,31,33,34,37,39,41,43,44';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 21 <strong>control</strong><br>0,1,9,14,20,21,22,24,25,26,27,30,32,36,40,42,45,47,48,49,50';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 8 <br>2,13,15,17,18,35,38,46';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <br>3,4,5,6,7,8,10,11,12,16,19,23,28,29,31,33,34,37,39,41,43,44';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 21 <strong>control</strong><br>0,1,9,14,20,21,22,24,25,26,27,30,32,36,40,42,45,47,48,49,50';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 8 <br>2,13,15,17,18,35,38,46';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <br>3,4,5,6,7,8,10,11,12,16,19,23,28,29,31,33,34,37,39,41,43,44';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 21 <strong>control</strong><br>0,1,9,14,20,21,22,24,25,26,27,30,32,36,40,42,45,47,48,49,50';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 8 <br>2,13,15,17,18,35,38,46';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <br>3,4,5,6,7,8,10,11,12,16,19,23,28,29,31,33,34,37,39,41,43,44';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 21 <strong>control</strong><br>0,1,9,14,20,21,22,24,25,26,27,30,32,36,40,42,45,47,48,49,50';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 8 <br>2,13,15,17,18,35,38,46';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <br>3,4,5,6,7,8,10,11,12,16,19,23,28,29,31,33,34,37,39,41,43,44';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 21 <strong>control</strong><br>0,1,9,14,20,21,22,24,25,26,27,30,32,36,40,42,45,47,48,49,50';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 8 <br>2,13,15,17,18,35,38,46';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <br>3,4,5,6,7,8,10,11,12,16,19,23,28,29,31,33,34,37,39,41,43,44';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>42</strong> miembros: 21 <strong>control</strong><br>0,1,9,14,20,21,22,24,25,26,27,30,32,36,40,42,45,47,48,49,50';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260821 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>2</strong> miembros: 8 <br>2,13,15,17,18,35,38,46';}
}
